@@ -38,7 +38,7 @@ Usage::
     list_worlds_paginator: ListWorldsPaginator = client.get_paginator("list_worlds")
     ```
 """
-from typing import Generic, Iterator, List, TypeVar
+from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -86,43 +86,43 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListDeploymentJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listdeploymentjobspaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListDeploymentJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listdeploymentjobspaginator)
         """
 
 
 class ListFleetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listfleetspaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListFleetsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listfleetspaginator)
         """
 
 
 class ListRobotApplicationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listrobotapplicationspaginator)
     """
 
@@ -130,36 +130,36 @@ class ListRobotApplicationsPaginator(Boto3Paginator):
         self,
         *,
         versionQualifier: str = None,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListRobotApplicationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listrobotapplicationspaginator)
         """
 
 
 class ListRobotsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listrobotspaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListRobotsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listrobotspaginator)
         """
 
 
 class ListSimulationApplicationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listsimulationapplicationspaginator)
     """
 
@@ -167,90 +167,90 @@ class ListSimulationApplicationsPaginator(Boto3Paginator):
         self,
         *,
         versionQualifier: str = None,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListSimulationApplicationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listsimulationapplicationspaginator)
         """
 
 
 class ListSimulationJobBatchesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listsimulationjobbatchespaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListSimulationJobBatchesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listsimulationjobbatchespaginator)
         """
 
 
 class ListSimulationJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listsimulationjobspaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListSimulationJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listsimulationjobspaginator)
         """
 
 
 class ListWorldExportJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldExportJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldExportJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldexportjobspaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListWorldExportJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldExportJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldExportJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldexportjobspaginator)
         """
 
 
 class ListWorldGenerationJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldGenerationJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldGenerationJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldgenerationjobspaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListWorldGenerationJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldGenerationJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldGenerationJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldgenerationjobspaginator)
         """
 
 
 class ListWorldTemplatesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldTemplates)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldTemplates)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldtemplatespaginator)
     """
 
@@ -258,24 +258,24 @@ class ListWorldTemplatesPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListWorldTemplatesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldTemplates.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldTemplates.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldtemplatespaginator)
         """
 
 
 class ListWorldsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorlds)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorlds)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldspaginator)
     """
 
     def paginate(
         self,
         *,
-        filters: List["FilterTypeDef"] = None,
+        filters: Sequence["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListWorldsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/robomaker.html#RoboMaker.Paginator.ListWorlds.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/robomaker.html#RoboMaker.Paginator.ListWorlds.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators.html#listworldspaginator)
         """
